==> base-domain-0.0.3-20170113.034120-64-sources.jar: com/thebeastshop/scm/po/InterestSku.java <==
package com.thebeastshop.scm.po;

import java.util.Date;

import pers.richard.ormybatis.domain.po.IdPo;

public class InterestSku extends IdPo {
	private Integer interestId;
	private String skuCode;
	private String skuNameCn;
	private Integer quantity;
	private Integer receiveQuantity;
	private Date updateTime;
	private Date createTime;
	
	public InterestSku(){}
	
	public final static String
		F_INTEREST_ID = "interest_id",
		F_SKU_CODE = "sku_code",
		F_SKU_NAME_CN = "sku_name_cn",
		F_QUANTITY = "quantity",
		F_RECEIVE_QUANTITY = "receive_quantity",
		F_UPDATE_TIME = "update_time",
		F_CREATE_TIME = "create_time";
	

	public Integer getInterestId() {return interestId;}
	public void setInterestId(Integer interestId) {this.interestId = interestId;}

	public String getSkuCode() {return skuCode;}
	public void setSkuCode(String skuCode) {this.skuCode = skuCode;}

	public String getSkuNameCn() {return skuNameCn;}
	public void setSkuNameCn(String skuNameCn) {this.skuNameCn = skuNameCn;}
	
	public Integer getQuantity() {return quantity;}
	public void setQuantity(Integer quantity) {this.quantity = quantity;}

	public Integer getReceiveQuantity() {return receiveQuantity;}
	public void setReceiveQuantity(Integer receiveQuantity) {this.receiveQuantity = receiveQuantity;}

	public Date getUpdateTime() {return updateTime;}
	public void setUpdateTime(Date updateTime) {this.updateTime = updateTime;}

	public Date getCreateTime() {return createTime;}
	public void setCreateTime(Date createTime) {this.createTime = createTime;}
}

==> base-domain-0.0.3-20170118.043834-76-sources.jar: com/thebeastshop/scm/po/InterestSku.java <==
package com.thebeastshop.scm.po;

import java.util.Date;

import pers.richard.ormybatis.domain.po.IdPo;

public class InterestSku extends IdPo {
	private Integer interestId;
	private String skuCode;
	private String skuNameCn;
	private Integer quantity;
	private Integer receiveQuantity;
	private Integer version;
	private Date updateTime;
	private Date createTime;
	
	public InterestSku(){}
	
	public final static String
		F_INTEREST_ID = "interest_id",
		F_SKU_CODE = "sku_code",
		F_SKU_NAME_CN = "sku_name_cn",
		F_QUANTITY = "quantity",
		F_RECEIVE_QUANTITY = "receive_quantity",
		F_VERSION = "version",
		F_UPDATE_TIME = "update_time",
		F_CREATE_TIME = "create_time";
	

	public Integer getInterestId() {return interestId;}
	public void setInterestId(Integer interestId) {this.interestId = interestId;}

	public String getSkuCode() {return skuCode;}
	public void setSkuCode(String skuCode) {this.skuCode = skuCode;}

	public String getSkuNameCn() {return skuNameCn;}
	public void setSkuNameCn(String skuNameCn) {this.skuNameCn = skuNameCn;}
	
	public Integer getQuantity() {return quantity;}
	public void setQuantity(Integer quantity) {this.quantity = quantity;}

	public Integer getReceiveQuantity() {return receiveQuantity;}
	public void setReceiveQuantity(Integer receiveQuantity) {this.receiveQuantity = receiveQuantity;}

	public Integer getVersion() {return version;}
	public void setVersion(Integer version) {this.version = version;}
	
	public Date getUpdateTime() {return updateTime;}
	public void setUpdateTime(Date updateTime) {this.updateTime = updateTime;}

	public Date getCreateTime() {return createTime;}
	public void setCreateTime(Date createTime) {this.createTime = createTime;}
}
